summaryrefslogtreecommitdiff
path: root/source4/torture/t_strcmp.c
diff options
context:
space:
mode:
Diffstat (limited to 'source4/torture/t_strcmp.c')
-rw-r--r--source4/torture/t_strcmp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source4/torture/t_strcmp.c b/source4/torture/t_strcmp.c
index 622769001b..15d000c98f 100644
--- a/source4/torture/t_strcmp.c
+++ b/source4/torture/t_strcmp.c
@@ -1,7 +1,7 @@
/*
* Copyright (C) 2003 by Martin Pool
*
* Test harness for StrCaseCmp
*/
#include "includes.h"
@@ -14,7 +14,7 @@ int main(int argc, char *argv[])
return 2;
}
- printf("%d\n", StrCaseCmp(argv[1], argv[2]));
+ printf("%d\n", strcasecmp_m(argv[1], argv[2]));
return 0;
}
@@ -1,7 +1,7 @@
* Copyright (C) 2003 by Martin Pool
*
- * Test harness for StrCaseCmp
+ * Test harness for strcasecmp_m
*/
#include "includes.h"